@@ -42,7 +42,7 @@ use Data::Dumper;
 use parent qw(WebService::ILS::JSON);
 
 use constant API_VERSION => "v1";
-use constant DEFAULT_DOMAIN => "oneclickdigital.us";
+use constant DEFAULT_DOMAIN => "oneclickdigital.com";
 
 =head1 CONSTRUCTOR
 
@@ -66,9 +66,9 @@ C<client_id> is either OneClickDigital id (barcode) or email
 
 use Class::Tiny qw(
     ssl
+    country
     _api_base_url
 ), {
-    country => "US",
     domain => DEFAULT_DOMAIN,
 };
 
@@ -92,21 +92,25 @@ sub BUILD {
 
     my $api_url = sprintf "%s://api.%s", $ssl ? "https" : "http", $domain;
     $self->_api_base_url($api_url);
-    local $@;
-    my $data = eval { $self->native_countries };
-    if (!$data && $domain ne DEFAULT_DOMAIN) {
-        $domain = DEFAULT_DOMAIN;
-        $api_url = sprintf "%s://api.%s", $ssl ? "https" : "http", $domain;
-        $self->_api_base_url($api_url);
-        $data = $self->native_countries;
-    }
 
-    my $country = uc $self->country;
-    foreach (@$data) {
-        $api_url = $_->{oneClickApi} or next;
-        if (grep { $_ eq $country } ($_->{isoA2}, $_->{isoA3})) {
+    if (my $country = $self->country) {
+        $country = uc $country;
+        local $@;
+        my $data = eval { $self->native_countries };
+        if (!$data && $domain ne DEFAULT_DOMAIN) {
+            # temporary use DEFAULT_DOMAIN to get the list of countries
+            $api_url = sprintf "%s://api.%s", $ssl ? "https" : "http", DEFAULT_DOMAIN;
             $self->_api_base_url($api_url);
-            last;
+            $data = $self->native_countries;
+            $api_url = sprintf "%s://api.%s", $ssl ? "https" : "http", $domain;
+            $self->_api_base_url($api_url);
+        }
+        foreach (@$data) {
+            $api_url = $_->{oneClickApi} or next;
+            if (grep { $_ eq $country } ($_->{isoA2}, $_->{isoA3})) {
+                $self->_api_base_url($api_url);
+                last;
+            }
         }
     }
 }
